@@ -1,4 +1,4 @@
 export {DefaultBufferLength, NodeProp, MountedTree, NodePropSource, NodeType, NodeSet, Tree,
-        TreeBuffer, SyntaxNode, SyntaxNodeRef, TreeCursor, BufferCursor, NodeWeakMap, IterMode} from "./tree"
+        TreeBuffer, SyntaxNode, SyntaxNodeRef, TreeCursor, BufferCursor, NodeWeakMap, IterMode, NodeIterator} from "./tree"
 export {ChangedRange, TreeFragment, PartialParse, Parser, Input, ParseWrapper} from "./parse"
 export {NestedParse, parseMixed} from "./mix"
